@@ -23,14 +23,14 @@ http://github.com/FMCorz/mdk
 """
 
 import os
-import urllib
+import urllib.request, urllib.parse, urllib.error
 import re
 import logging
 import gzip
 from tempfile import gettempdir
 from time import sleep
 from ..command import Command
-from ..tools import process, ProcessInThread, downloadProcessHook, question
+from ..tools import process, ProcessInThread, downloadProcessHook, question, natural_sort_key
 
 
 class BehatCommand(Command):
@@ -171,8 +171,8 @@ class BehatCommand(Command):
             logging.info('Installing Composer')
             cliFile = 'behat_install_composer.php'
             cliPath = os.path.join(M.get('path'), 'behat_install_composer.php')
-            (to, headers) = urllib.urlretrieve('http://getcomposer.org/installer', cliPath)
-            if headers.dict.get('content-encoding') == 'gzip':
+            (to, headers) = urllib.request.urlretrieve('http://getcomposer.org/installer', cliPath)
+            if dict(headers).get('content-encoding') == 'gzip':
                 f = gzip.open(cliPath, 'r')
                 content = f.read()
                 f.close()
@@ -189,17 +189,20 @@ class BehatCommand(Command):
             seleniumPath = args.selenium
         elif args.seleniumforcedl or (not nojavascript and not os.path.isfile(seleniumPath)):
             logging.info('Attempting to find a download for Selenium')
-            url = urllib.urlopen('http://docs.seleniumhq.org/download/')
-            content = url.read()
-            selenium = re.search(r'http:[a-z0-9/._-]+selenium-server-standalone-[0-9.]+\.jar', content, re.I)
-            if selenium:
-                logging.info('Downloading Selenium from %s' % (selenium.group(0)))
+            seleniumStorageUrl = 'https://selenium-release.storage.googleapis.com/'
+            url = urllib.request.urlopen(seleniumStorageUrl)
+            content = url.read().decode('utf-8')
+            matches = sorted(re.findall(r'[a-z0-9._-]+/selenium-server-standalone-[0-9.]+\.jar', content, re.I),
+                             key=natural_sort_key)
+            if len(matches) > 0:
+                seleniumUrl = seleniumStorageUrl + matches[-1]
+                logging.info('Downloading Selenium from %s' % seleniumUrl)
                 if (logging.getLogger().level <= logging.INFO):
-                    urllib.urlretrieve(selenium.group(0), seleniumPath, downloadProcessHook)
+                    urllib.request.urlretrieve(seleniumUrl, seleniumPath, downloadProcessHook)
                     # Force a new line after the hook display
                     logging.info('')
                 else:
-                    urllib.urlretrieve(selenium.group(0), seleniumPath)
+                    urllib.request.urlretrieve(seleniumUrl, seleniumPath)
             else:
                 logging.warning('Could not locate Selenium server to download')
 
@@ -236,10 +239,20 @@ class BehatCommand(Command):
                 cmd.append('--tags ~@javascript')
 
             if args.faildump:
-                cmd.append('--format="progress,progress,html,failed"')
-                cmd.append('--out=",{0}/progress.txt,{0}/status.html,{0}/failed.txt"'.format(outputDir))
+                if M.branch_compare(31, '<'):
+                    cmd.append('--format="progress,progress,pretty,html,failed"')
+                    cmd.append('--out=",{0}/progress.txt,{0}/pretty.txt,{0}/status.html,{0}/failed.txt"'.format(outputDir))
+                else:
+                    cmd.append('--format="moodle_progress" --out="std"')
+                    cmd.append('--format="progress" --out="{0}/progress.txt"'.format(outputDir))
+                    cmd.append('--format="pretty" --out="{0}/pretty.txt"'.format(outputDir))
 
-            cmd.append('--config=%s/behat/behat.yml' % (M.get('behat_dataroot')))
+            configcandidates = ['%s/behat/behat.yml' % (M.get('behat_dataroot'))]
+            if M.branch_compare(32):
+                # Since Moodle 3.2.2 behat directory is kept under $CFG->behat_dataroot for single and parallel runs.
+                configcandidates.insert(0, '%s/behatrun/behat/behat.yml' % (M.get('behat_dataroot')))
+
+            cmd.append('--config=%s' % (list(filter(os.path.isfile, configcandidates))[0]))
 
             # Checking feature argument
             if args.feature:
